==> Ceph-Lib-Rbd-0.01.tgz: Ceph-Lib-Rbd/lib/Ceph/Lib/Rbd.pm <==
package Ceph::Lib::Rbd;

use 5.006;
use strict;
use warnings;

=head1 NAME

Ceph::Lib::Rbd - The great new Ceph::Lib::Rbd!

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.01';


=head1 SYNOPSIS

Quick summary of what the module does.

Perhaps a little code snippet.

    use Ceph::Lib::Rbd;

    my $foo = Ceph::Lib::Rbd->new();
    ...

=head1 EXPORT

A list of functions that can be exported.  You can delete this section
if you don't export anything, such as for a purely object-oriented module.

=head1 SUBROUTINES/METHODS

=head2 function1

=cut

sub function1 {
}

=head2 function2

=cut

sub function2 {
}

=head1 AUTHOR

Yonghua Peng, C<< <pyh at cloud-china.org> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-ceph-lib-rbd at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Ceph-Lib-Rbd>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Ceph::Lib::Rbd


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Ceph-Lib-Rbd>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Ceph-Lib-Rbd>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Ceph-Lib-Rbd>

=item * Search CPAN

L<http://search.cpan.org/dist/Ceph-Lib-Rbd/>

=back


=head1 ACKNOWLEDGEMENTS


=head1 LICENSE AND COPYRIGHT

Copyright 2015 Yonghua Peng.

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.


=cut

1; # End of Ceph::Lib::Rbd

==> Ceph-Lib-Rbd-0.02.tgz: Ceph-Lib-Rbd/lib/Ceph/Lib/Rbd.pm <==
package Ceph::Lib::Rbd;

use 5.006;
use strict;
use warnings;

=head1 NAME

Ceph::Lib::Rbd - Perl wrapper to librbd

=head1 VERSION

Version 0.02

=cut

our $VERSION = '0.02';


=head1 SYNOPSIS

This module provides perl's librbd API.


    use Ceph::Lib::Rbd;

    my $rbd = Ceph::Lib::Rbd->new();
    ...


=head1 METHODS

This module still in development, we will release it soon.


=head1 AUTHOR

Chun Zhang <zhangchun@yy.com>

Yonghua Peng <pengyonghua@yy.com>

=head1 BUGS

Please report any bugs or feature requests to C<bug-ceph-lib-rbd at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Ceph-Lib-Rbd>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.


=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Ceph::Lib::Rbd


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Ceph-Lib-Rbd>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Ceph-Lib-Rbd>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Ceph-Lib-Rbd>

=item * Search CPAN

L<http://search.cpan.org/dist/Ceph-Lib-Rbd/>

=back


=head1 ACKNOWLEDGEMENTS


=head1 LICENSE AND COPYRIGHT

Copyright 2015 Yonghua Peng.

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.


=cut

1; # End of Ceph::Lib::Rbd
